@@ -1,8 +1,7 @@
 import requests
-import random
-import string
-from iso8601 import parse_date
+import time
 import pytz
+from iso8601 import parse_date
 from ..MuviBase import MuviBase
 
 map_errors = {
@@ -104,8 +103,8 @@ def _format(response):
         response['status_detail'] = 'refunded'
     date = parse_date(response['date']).astimezone(arg_tz)
     result = {
-        'id': response['site_transaction_id'],
-        'payment_id': response['id'],
+        'id': int(response['site_transaction_id']), # Generado por el sdk
+        'payment_id': response['id'],               # Genereador por decidir
         'transaction_amount': response['amount'] / 100,
         'date_created': date,
         'status': response['status'],
@@ -137,7 +136,7 @@ class Payment(MuviBase):
         }
 
     def create(self, payment_data: dict):
-        site_transaction_id = ''.join(random.choices(string.ascii_letters + string.digits, k=10))
+        site_transaction_id = int(time.time()*1e2)
         total_amount = round(payment_data['transaction_amount'], 2) * 100  # se multiplica por 100; no acepta decimales
         installments = payment_data['installments'] if 'installments' in payment_data else 1
         body = {
@@ -146,7 +145,7 @@ class Payment(MuviBase):
                 'email': payment_data['payer']['email']
             },
             'site_id': self.site_id_cadena if self.marketplace else self.site_id,
-            'site_transaction_id': site_transaction_id,
+            'site_transaction_id': str(site_transaction_id),
             'token': payment_data['token'],
             'payment_method_id': payment_data['payment_method_id'] if 'payment_method_id' in payment_data else 1,
             'bin': payment_data['bin'],     # primeros 6 digitos de la tarjeta
@@ -192,9 +191,9 @@ class Payment(MuviBase):
             return self.ok(response=_format(response))
         return self.error(response=response, status=r.status_code)
 
-    def get(self, payment_id: str):
+    def get(self, payment_id):
         filters = {
-            'siteOperationId': payment_id,
+            'siteOperationId': int(payment_id),
             'expand': 'card_data'
         }
         r = requests.get(self.url + '/payments', params=filters, headers=self.headers)
